@@ -528,7 +528,7 @@ extract_messages()
 {
 podir=${podir:-$PWD/po}
 files=`find . -name Makefile.am | xargs egrep -l '^messages:' `
-dirs=`for i in $files; do echo \`dirname $i\`; done`
+dirs=`for i in $files; do echo \`dirname $i\`; done | sort -r`
 tmpname="$PWD/messages.log"
 if test -z "$EXTRACTRC"; then EXTRACTRC=extractrc ; fi
 if test -z "$PREPARETIPS"; then PREPARETIPS=preparetips ; fi
@@ -565,7 +565,7 @@ for subdir in $dirs; do
    fi
    ) 2>&1 | grep -v '^make\[1\]' > $tmpname
    test -s $tmpname && { echo $subdir ; cat "$tmpname"; }
-   test -f $subdir/rc.cpp && rm -f $subdir/rc.cpp
+   # test -f $subdir/rc.cpp && rm -f $subdir/rc.cpp
    rm -f $subdir/_translatorinfo.cpp
    rm -f $subdir/_transMakefile
 done
@@ -629,8 +629,9 @@ if test -f Makefile.am.in; then
   rm -f $makefile_wo
 fi
 
-# Suck in the AUTOCONF detection code
-. $admindir/detect-autoconf.sh
+# Call script to find autoconf and freinds. Uses eval since the script outputs
+# sh-compatible code.
+eval `$admindir/detect-autoconf.pl`
 
 ###
 ### Main
