@@ -37,6 +37,7 @@ email                : mte@users.sourceforge.net
 #ifndef _GNCFILEANON
   #include <klocale.h>
   #include <kconfig.h>
+  #include <kmessagebox.h>
 #endif
 
 // ----------------------------------------------------------------------------
@@ -1756,13 +1757,11 @@ void MyMoneyGncReader::terminate () {
     /* fix for qt3.3.4?. According to Qt docs, this should return the enum id of the button pressed, and
        indeed it used to do so. However now it seems to return the index of the button. In this case it doesn't matter,
        since for Yes, the id is 3 and the index is 0, whereas the No button will return 4 or 1. So we test for either Yes case */
-    switch (QMessageBox::question (0, PACKAGE,
-        i18n("Your main currency seems to be %1 (%2); do you want to set this as your base currency?")
-            .arg(mainCurrency).arg(m_storage->currency(mainCurrency.utf8()).name()),
-                    QMessageBox::Yes | QMessageBox::Default, QMessageBox::No)) {
-        case 0:
-        case QMessageBox::Yes:
-          m_storage->setValue ("kmm-baseCurrency", mainCurrency);
+    /* and now it seems to have changed again, returning 259 for a Yes??? so use KMessagebox */
+    QString question = i18n("Your main currency seems to be %1 (%2); do you want to set this as your base currency?")
+        .arg(mainCurrency).arg(m_storage->currency(mainCurrency.utf8()).name());
+    if(KMessageBox::questionYesNo(0, question, PACKAGE) == KMessageBox::Yes) {
+      m_storage->setValue ("kmm-baseCurrency", mainCurrency);
     }
   }
   // now produce the end of job reports - first, work out which ones are required
