@@ -63,6 +63,9 @@ KEnterScheduleDialog::KEnterScheduleDialog(QWidget *parent, const MyMoneySchedul
   initWidgets();
   calculateInterest();
 
+  if(m_schedule.id().isEmpty())
+    m_buttonOk->setEnabled(false);
+
   connect(m_splitButton, SIGNAL(clicked()), this, SLOT(slotSplitClicked()));
   connect(m_buttonOk, SIGNAL(clicked()), this, SLOT(slotOK()));
   connect(m_from, SIGNAL(accountSelected(const QCString&)),
@@ -132,34 +135,39 @@ void KEnterScheduleDialog::initWidgets()
   {
     try
     {
-    MyMoneySplit amortizationSplit;
-    QValueList<MyMoneySplit>::ConstIterator it_s;
-    for(it_s = m_transaction.splits().begin(); it_s != m_transaction.splits().end(); ++it_s) {
-      if((*it_s).value() == MyMoneyMoney::autoCalc
-      && (*it_s).action() == MyMoneySplit::ActionAmortization) {
-        MyMoneyAccount acc = MyMoneyFile::instance()->account((*it_s).accountId());
-        switch(acc.accountType()) {
-          case MyMoneyAccount::Loan:
-            m_from->setEnabled(true);
-            m_to->setEnabled(false);
-            m_from->loadList((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
-            loanAccount = m_from;
-            break;
+      MyMoneySplit amortizationSplit;
+      QValueList<MyMoneySplit>::ConstIterator it_s;
+      for(it_s = m_transaction.splits().begin(); it_s != m_transaction.splits().end(); ++it_s) {
+        if((*it_s).value() == MyMoneyMoney::autoCalc
+        && (*it_s).action() == MyMoneySplit::ActionAmortization) {
+          MyMoneyAccount acc = MyMoneyFile::instance()->account((*it_s).accountId());
+          switch(acc.accountType()) {
+            case MyMoneyAccount::Loan:
+              m_from->setEnabled(true);
+              m_to->setEnabled(false);
+              m_from->loadList((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
+              loanAccount = m_from;
+              break;
 
-          case MyMoneyAccount::AssetLoan:
-            m_from->setEnabled(false);
-            m_to->setEnabled(true);
-            m_to->loadList((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
-            loanAccount = m_to;
-            break;
+            case MyMoneyAccount::AssetLoan:
+              m_from->setEnabled(false);
+              m_to->setEnabled(true);
+              m_to->loadList((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
+              loanAccount = m_to;
+              break;
 
-          default:
-            qFatal("invalid account type in %s:%d", __FILE__, __LINE__);
-            break;
+            default:
+              qFatal("invalid account type in %s:%d", __FILE__, __LINE__);
+              break;
+          }
+          break;
         }
-        break;
       }
-    }
+      if(loanAccount == 0) {
+        KMessageBox::detailedError(this, i18n("Unable to load schedule details"), i18n("The schedule %1 caused an internal problem. Please contact the developers via e-mail on kmymoney2-developer@lists.sourceforge.net for further instructions mentioning this problem.").arg(m_schedule.id()));
+        m_schedule = MyMoneySchedule();
+        return;
+      }
     }
     catch (MyMoneyException* e)
     {
@@ -359,6 +367,10 @@ bool KEnterScheduleDialog::checkData(void)
   int noItemsChanged=0;
   QString payeeName;
 
+  // if no schedule is present, we cannot enter it
+  if(m_schedule.id().isEmpty())
+    return false;
+
   if (m_fromAccountId == m_toAccountId)
   {
     KMessageBox::error(this, i18n("Account and transfer account are the same.  Please change one."));
@@ -1000,7 +1012,8 @@ void KEnterScheduleDialog::slotFromActivated(const QCString& id)
 {
   if (m_schedule.type() != MyMoneySchedule::TYPE_DEPOSIT)
   {
-    // Change the splits because otherwise they wont be found
+    m_fromAccountId = id;
+    // Change the splits because otherwise they won't be found
     // if the user clicks on the split button
     MyMoneySplit s = m_transaction.splits()[0];
     s.setAccountId(id);
@@ -1012,7 +1025,8 @@ void KEnterScheduleDialog::slotToActivated(const QCString& id)
 {
   if (m_schedule.type() == MyMoneySchedule::TYPE_DEPOSIT)
   {
-    // Change the splits because otherwise they wont be found
+    m_toAccountId = id;
+    // Change the splits because otherwise they won't be found
     // if the user clicks on the split button
     MyMoneySplit s = m_transaction.splits()[0];
     s.setAccountId(id);
