@@ -343,10 +343,19 @@ void KEquityPriceUpdateDlg::slotReceivedQuote(const QString& _id, const QString&
       if ( date > QDate::currentDate() )
         date = QDate::currentDate();
 
+      double price = _price;
+      QCString id = _id.utf8();
       MyMoneySecurity sec;
+
       if(_id.contains(" ") == 0) {      // it's a normal symbol no currency conversion
+        MyMoneySecurity security = MyMoneyFile::instance()->security(id);
+        QString factor = security.value("kmm-online-factor");
+        if(!factor.isEmpty()) {
+          price *= MyMoneyMoney(factor).toDouble();
+        }
+
         try {
-          sec = MyMoneyFile::instance()->security(QCString(_id));
+          sec = MyMoneyFile::instance()->security(id);
           sec = MyMoneyFile::instance()->security(sec.tradingCurrency());
         } catch(MyMoneyException *e) {
           sec = MyMoneySecurity();
@@ -362,7 +371,7 @@ void KEquityPriceUpdateDlg::slotReceivedQuote(const QString& _id, const QString&
           }
         }
       }
-      item->setText(PRICE_COL, KGlobal::locale()->formatMoney(_price,sec.tradingSymbol(),m_pricePrecision));
+      item->setText(PRICE_COL, KGlobal::locale()->formatMoney(price,sec.tradingSymbol(),m_pricePrecision));
       item->setText(DATE_COL, date.toString(Qt::ISODate));
       logStatusMessage(i18n("Price for %1 updated").arg(_symbol));
     }
