@@ -1593,6 +1593,8 @@ void KLedgerView::slotEndEdit(void)
         it_p = priceInfo.find(key);
 
         // if it's not found, then collect it from the user first
+        // if there's a price stored in the current transaction provide it as default
+        // if it's a new transaction go and search the price db for info
         MyMoneyMoney price;
         if(it_p == priceInfo.end()) {
           MyMoneySecurity fromCurrency, toCurrency;
@@ -1612,10 +1614,19 @@ void KLedgerView::slotEndEdit(void)
           // make sure either to and from are zero or both are not zero
           if((fromValue.isZero() && !toValue.isZero())
           || (!fromValue.isZero() && toValue.isZero())) {
-            if(fromValue.isZero())
-              fromValue = toValue;
-            if(toValue.isZero())
-              toValue = fromValue;
+            MyMoneyPrice price = file->price(fromCurrency.id(), toCurrency.id());
+            if(fromValue.isZero()) {
+              if(price.isValid())
+                fromValue = file->price(fromCurrency.id(), toCurrency.id()).rate(fromCurrency.id()) * toValue;
+              else
+                fromValue = toValue;
+            }
+            if(toValue.isZero()) {
+              if(price.isValid())
+                toValue = file->price(fromCurrency.id(), toCurrency.id()).rate(toCurrency.id()) * fromValue;
+              else
+                toValue = fromValue;
+            }
           }
 
           KCurrencyCalculator calc(fromCurrency,
@@ -2227,5 +2238,4 @@ bool KLedgerView::eventFilter(QObject* o, QEvent* e)
   return rc;
 }
 
-
 #include "kledgerview.moc"
