@@ -1381,6 +1381,9 @@ QWidget* KLedgerViewCheckings::arrangeEditWidgetsInRegister(void)
   if(m_editSplit) {
     delete m_editSplit;
   }
+  m_editPayee->setHint(i18n("Payee"));
+  m_editCategory->setHint(i18n("Category/Account"));
+  m_editMemo->setHint(i18n("Memo"));
   return focusWidget;
 }
 
@@ -1719,10 +1722,19 @@ void KLedgerViewCheckings::slotOpenSplitDialog(void)
       isValidAmount = true;
     }
   }
+
+  int direction = transactionDirection(m_split);
+  if(direction == UnknownDirection) {
+    direction = Debit;
+    if(currentActionTab() == 1) {    // Deposit?
+      direction = Credit;
+    }
+  }
+
   KSplitTransactionDlg* dlg = new KSplitTransactionDlg(m_transaction,
                                                        m_account,
                                                        isValidAmount,
-                                                       transactionDirection(m_split) == Credit,
+                                                       direction == Credit,
                                                        0,
                                                        this);
 
