@@ -1581,6 +1581,7 @@ void KMyMoneyView::loadDefaultCurrencies(void)
   bool create = MyMoneyFile::instance()->currencyList().count() == 0;
   loadDefaultCurrency(MyMoneySecurity("AFA", i18n("Afghanistan Afghani")), create);
   loadDefaultCurrency(MyMoneySecurity("ALL", i18n("Albanian Lek")), create);
+  loadDefaultCurrency(MyMoneySecurity("ANG", i18n("Netherland Antillian Guilder")), create);
   loadDefaultCurrency(MyMoneySecurity("DZD", i18n("Algerian Dinar")), create);
   loadDefaultCurrency(MyMoneySecurity("ADF", i18n("Andorran Franc")), create);
   loadDefaultCurrency(MyMoneySecurity("ADP", i18n("Andorran Peseta")), create);
@@ -1696,7 +1697,7 @@ void KMyMoneyView::loadDefaultCurrencies(void)
   loadDefaultCurrency(MyMoneySecurity("PLN", i18n("Polish Zloty")), create);
   loadDefaultCurrency(MyMoneySecurity("QAR", i18n("Qatari Rial")), create);
   loadDefaultCurrency(MyMoneySecurity("RON", i18n("Romanian Leu (new)")), true);
-  loadDefaultCurrency(MyMoneySecurity("RUR", i18n("Russian Ruble")), create);
+  loadDefaultCurrency(MyMoneySecurity("RUB", i18n("Russian Ruble")), true);
   loadDefaultCurrency(MyMoneySecurity("RWF", i18n("Rwanda Franc")), create);
   loadDefaultCurrency(MyMoneySecurity("WST", i18n("Samoan Tala")), create);
   loadDefaultCurrency(MyMoneySecurity("STD", i18n("Sao Tome and Principe Dobra")), create);
@@ -1787,7 +1788,7 @@ void KMyMoneyView::loadAncientCurrencies(void)
   loadAncientCurrency("FIM", i18n("Finnish Markka"), QCString(), QDate(1998,12,31), MyMoneyMoney(100000, 594573), "EUR");
   loadAncientCurrency("GRD", i18n("Greek Drachma"), QChar(0x20AF), QDate(1998,12,31), MyMoneyMoney(100, 34075), "EUR");
   loadAncientCurrency("ROL", i18n("Romanian Leu"), "ROL", QDate(2005,6,30), MyMoneyMoney(1, 10000), "RON");
-}
+  loadAncientCurrency("RUR", i18n("Russian Ruble (old)"), "RUR", QDate(1998, 1, 1), MyMoneyMoney(1, 1000), "RUB");}
 
 # if 0
 // I leave that in here for now to be able to see what
